@@ -921,6 +921,7 @@ static void smtp_connect_inet(SMTP_STATE *state, const char *nexthop,
 	 */
 #ifdef USE_TLSRPT
 	if (smtp_mode && var_smtp_tlsrpt_enable
+	    && tls_level_lookup(var_smtp_tls_level) > TLS_LEV_NONE
 	    && !valid_hostaddr(domain, DONT_GRIPE))
 	    smtp_tlsrpt_create_wrapper(state, domain);
 	else
@@ -1099,7 +1100,7 @@ static void smtp_connect_inet(SMTP_STATE *state, const char *nexthop,
 		 * problem, then we must report correct information.
 		 */
 #ifdef USE_TLSRPT
-		if (state->tlsrpt && state->tls->level > TLS_LEV_NONE) {
+		if (state->tlsrpt) {
 		    smtp_tlsrpt_set_tls_policy(state);
 		    smtp_tlsrpt_set_tcp_connection(state);
 		}
